@@ -1,8 +1,8 @@
 ﻿#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import os, sys
-from PyQt4 import QtGui, QtCore
+import os, sys, time
+from PyQt4 import QtGui, QtCore, Qt
 import QonsoFactory
 from QonsoModel import QonsoModel
 from DlgConfig import DlgConfig
@@ -16,6 +16,7 @@ class QonsoView(QtGui.QMainWindow):
       DebugLog("QonsoView::Init")
       self.offline = os.environ.has_key('OFFLINE')
       self.setMaximumSize(QtCore.QSize(800, 480))
+      self.setMinimumSize(QtCore.QSize(480, 480))
       self.setWindowTitle('Qonso')
 
       self.vbox = None
@@ -111,9 +112,12 @@ class QonsoView(QtGui.QMainWindow):
       file = menubar.addMenu('&Options')
       file.addAction(exit)
 
-      compteBox = self.CreateLayout('lasttime', None)
-      self.vbox.addLayout(compteBox)
+      self.statusBox = self.CreateLayout('status', None, True)
+      # self.labels['status'][1].setRange( 0, 100 )
+      # self.labels['status'][1].setShowRules(False)
+      # self.labels['status'][1].setYTop(0)
       
+      self.vbox.addLayout(self.statusBox)
       self.vbox.setSpacing(0)
       self.vbox.setMargin(0)
    
@@ -124,6 +128,9 @@ class QonsoView(QtGui.QMainWindow):
       if not os.path.exists(iconPath):
          iconPath = 'icons'
       
+      self.boxes['compte'] = self.CreateLayout('lasttime', None)
+      self.vbox.addLayout(self.boxes['compte'])
+      
       self.boxes['voix'] = self.CreateLayout('voix', os.path.join(iconPath, 'voix.png'), True)
       self.vbox.addLayout(self.boxes['voix'])
       
@@ -184,6 +191,8 @@ class QonsoView(QtGui.QMainWindow):
       wid = None
       
       if progress:
+         # wid = QtGui.QProgressBar()
+         # wid.setTextVisible(False)
          wid = WProgress(self)
          wid.setStyleSheet("background: #fff; margin: 0; padding: 10px; border-bottom: 1px solid #269CCA")
          vbox.addWidget(wid)
@@ -201,16 +210,35 @@ class QonsoView(QtGui.QMainWindow):
          return 
       
       status, context = self.extractor.GetStatus()
-      
+
       if status=='ERROR':
-         self.SetText(self.labels['lasttime'][0], "#FF0000", 15, context)
-      else:
-         if not self.model.GetLastTime():
-            self.SetText(self.labels['lasttime'][0], "#269CCA", 16, context)
-         else:
-            self.SetText(self.labels['lasttime'][0], "#269CCA", 16, self.model.GetLastTime()+
-                         "<br/>"+self.model.GetReport('str'))
+         self.SetText(self.labels['status'][0], "#F00", 16, context)
+         self.labels['status'][1].setValue( self.extractor.GetProgress() )
+
+      elif status=='DONE':
+         self.labels['status'][0].hide()
+         self.labels['status'][1].hide()
          
+      else:
+         context = context.strip()
+         pos = context.find(".")
+         if pos>1:
+            ppp = context[pos+1:]
+            ppplen = (len(ppp)+1)%4
+            context = context[:pos] + (1+ppplen)*"." + (3-ppplen)*" "
+
+         self.SetText(self.labels['status'][0], "#269CCA", 16, context)
+         self.labels['status'][0].setAlignment(QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
+         self.labels['status'][0].setStyleSheet("padding-left: 200px; background: white")
+         self.labels['status'][1].setValue( self.extractor.GetProgress() )
+         self.extractor.context = context
+         time.sleep(0.3)
+         self.update()
+         
+      if self.model.GetLastTime():
+         self.SetText(self.labels['lasttime'][0], "#269CCA", 16, self.model.GetLastTime()+
+                      "<br/>"+self.model.GetReport('str'))
+
       if self.labels.has_key('voix'):
          self.SetText(self.labels['voix'][0], "#EB5F18", 20, self.model.GetConsoVoix('str')+" / "+self.model.GetConsoVoixMax('str') )
          self.labels['voix'][1].setRange(0, self.model.GetConsoVoixMax('int'))
